import { IRuleEngine } from "@rtdb2/core";
import { Node, Operations, ServiceStatement, Operators } from "./parser";
export declare class CompilerError extends Error {
    node: Node;
    constructor(message: string, node: Node);
}
declare type Variables = {
    [key: string]: string | Variables;
};
declare class Variable {
    #private;
    constructor(name: string);
    getValue(variables: Variables): any;
}
declare class Value {
    #private;
    constructor(value: any);
    get value(): any;
}
declare type ConditionParameters = Value | ConditionMatcher | Variable;
declare class ConditionMatcher {
    #private;
    constructor(left: ConditionParameters, right: ConditionParameters, operator: Operators);
    test(variables: Variables): boolean;
}
declare class Rule {
    #private;
    get operation(): Operations;
    constructor(operation: Operations, condition: ConditionParameters);
    test(variables: Variables): boolean;
}
declare class Segment {
    #private;
    get name(): string;
    constructor(name: string, variable?: boolean);
    match(segment: string): {
        match: boolean;
        variable?: string;
    };
}
declare class Match {
    #private;
    constructor(segments: Segment[], rules: Rule[], wildcard: boolean, submatches: Match[]);
    match(segments: string[], operation: Operations, variables: Variables): boolean;
}
export declare class RuleRunner implements IRuleEngine {
    #private;
    constructor(root_matches: Match[]);
    hasPermission(path: string[], operation: Operations, request: any): boolean;
}
export declare function getRuleRunner(service: ServiceStatement): RuleRunner;
export {};
