"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const error_1 = require("./error");
const parser_1 = require("./parser");
const tokenise_1 = require("./tokenise");
const compile_1 = require("./compile");
function compileRule(rule) {
    let runner;
    let error;
    try {
        const tokenised = tokenise_1.default(rule);
        const parsed = parser_1.default(tokenised);
        const dbservice = parsed.find((e) => e.name === "realtimedb");
        if (!dbservice)
            throw new Error("No realtimedb service available!");
        runner = compile_1.getRuleRunner(dbservice);
    }
    catch (err) {
        if (err instanceof tokenise_1.TokenizerError) {
            error = error_1.transformError(err, rule, err.index);
        }
        else if (err instanceof parser_1.ParserError) {
            error = error_1.transformError(err, rule, err.token.startIdx);
        }
        else {
            throw err;
        }
    }
    return { runner, error };
}
exports.default = compileRule;
//# sourceMappingURL=index.js.map