import { Operations } from "@rtdb2/core";
import { Token } from "./tokenise";
export interface Node {
    type: string;
    idx: number;
}
export interface PathStatement extends Node {
    type: "path";
    segments: (string | {
        type: "variable";
        name: string;
    })[];
}
export interface ValueStatement extends Node {
    type: "value";
    isNull: boolean;
    isTrue: boolean;
    isFalse: boolean;
    isNumber: boolean;
    isString: boolean;
    isVariable: boolean;
    value?: any;
}
export declare type Operators = "&&" | "||" | "==" | "<=" | ">=" | "!=" | ">" | "<";
export interface Expression extends Node {
    type: "expression";
    left: ValueStatement | Expression;
    operator: Operators;
    right: ValueStatement | Expression;
}
export type { Operations };
export interface AllowStatement extends Node {
    type: "permission";
    operations: Operations[];
    condition: Expression | ValueStatement;
}
export interface MatchStatement extends Node {
    type: "match";
    path: PathStatement;
    matches: MatchStatement[];
    rules: AllowStatement[];
}
export interface ServiceStatement extends Node {
    type: "service";
    name: string;
    matches: MatchStatement[];
}
export declare class ParserError extends Error {
    token: Token;
    constructor(message: string, token: Token);
}
export default function parse(tokens: Token[]): ServiceStatement[];
