"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenizerError = void 0;
class TokenizerError extends Error {
    constructor(message, index) {
        super(message);
        this.index = index;
    }
}
exports.TokenizerError = TokenizerError;
function regexMatcher(regex, type) {
    if (typeof regex === "string")
        regex = new RegExp(regex);
    return (input, index) => {
        let matches = input.substring(index).match(regex);
        if (!matches || matches.length <= 0)
            return undefined;
        return {
            type,
            value: matches[0],
            startIdx: index,
            endIdx: index + matches[0].length,
        };
    };
}
const matcher = [
    regexMatcher(/^\s+/, "space"),
    regexMatcher(/^\/\/.+/, "comment"),
    regexMatcher(/^#.+/, "comment"),
    regexMatcher(/^".*?"/, "string"),
    // regexMatcher(/(?<=^")(.*?)(?=")/, "string"),
    regexMatcher(/^(service|match|allow|if|true|false|null)/, "keyword"),
    regexMatcher(/^\:/, "colon"),
    regexMatcher(/^\;/, "semicolon"),
    regexMatcher(/^\,/, "comma"),
    regexMatcher(/^(\=\=|\!\=|\<\=|\>\=|\>|\<)/, "comparison_operator"),
    regexMatcher(/^(&&|\|\|)/, "logic_operator"),
    regexMatcher(/^\=/, "equals"),
    regexMatcher(/^\//, "slash"),
    regexMatcher(/^\(/, "bracket_open"),
    regexMatcher(/^\)/, "bracket_close"),
    regexMatcher(/^{/, "curly_open"),
    regexMatcher(/^}/, "curly_close"),
    regexMatcher(/^\[\]/, "array"),
    regexMatcher(/^\?/, "questionmark"),
    regexMatcher(/^[0-9]+(\.[0-9]+)?/, "number"),
    regexMatcher(/^[a-zA-Z_\*]([a-zA-Z0-9_\.\*]?)+/, "text"),
];
function tokenize(input) {
    let index = 0;
    let tokens = [];
    while (index < input.length) {
        const matches = matcher.map((m) => m(input, index)).filter((e) => !!e);
        let match = matches[0];
        if (match) {
            if (match.type !== "space" && match.type !== "comment") {
                tokens.push(match);
            }
            index += match.value.length;
        }
        else {
            throw new TokenizerError(`Unexpected token '${input.substring(index, index + 1)}'`, index);
        }
    }
    return tokens;
}
exports.default = tokenize;
//# sourceMappingURL=tokenise.js.map